@@ -1,14 +1,9 @@
 package Tapper::MCP;
-# git description: v4.1.1-16-g84f6d4c
+# git description: v4.1.2-37-gdb38db5
 
-BEGIN {
-  $Tapper::MCP::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::VERSION = '4.1.2';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Central master control program of Tapper automation
-
+$Tapper::MCP::VERSION = '5.0.0';
 use warnings;
 use strict;
 
@@ -26,25 +21,35 @@ sub cfg
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Tapper::MCP - Tapper - Central master control program of Tapper automation
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
