@@ -1,16 +1,13 @@
 package Tapper::MCP::Child;
-BEGIN {
-  $Tapper::MCP::Child::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Child::VERSION = '4.1.2';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Control one specific testrun on MCP side
-
+$Tapper::MCP::Child::VERSION = '5.0.0';
 use 5.010;
 use strict;
 use warnings;
+no warnings "experimental::smartmatch";
 
+use Class::Load 'load_class';
 use Hash::Merge::Simple qw/merge/;
 use List::Util qw(min max);
 use Moose;
@@ -21,6 +18,7 @@ use Tapper::MCP::Net;
 use Tapper::MCP::Config;
 use Tapper::Model 'model';
 use Tapper::MCP::State;
+use Tapper::MCP::Plugin;
 use Devel::Backtrace;
 
 use constant BUFLEN     => 1024;
@@ -28,10 +26,12 @@ use constant ONE_MINUTE => 60;
 
 extends 'Tapper::MCP::Control';
 with 'Tapper::MCP::Net::TAP';
+with 'Tapper::MCP::Plugin';
 
 has state    => (is => 'rw');
 has mcp_info => (is => 'rw');
 has rerun    => (is => 'rw', default => 0);
+has plugin_conf => (is => 'ro', default => sub {{}}, isa => 'HashRef'); # get the config for creating the plugin object
 
 
 sub get_messages
@@ -41,10 +41,11 @@ sub get_messages
         my $end_time = time() + $timeout;
 
         my $messages;
-        while () {
+        while (1) {
                 $messages = $self->testrun->message;
                 last if ($messages and $messages->count) or time() > $end_time;
-                sleep 1 unless $ENV{HARNESS_ACTIVE};
+                Tapper::Model::model('TestrunDB')->storage->disconnect;
+                sleep $self->cfg->{mcp}{child}{get_message_sleep_interval} unless $ENV{HARNESS_ACTIVE};
         }
         return $messages;
 }
@@ -72,16 +73,18 @@ sub wait_for_testrun
 sub generate_configs
 {
 
-        my ($self, $hostname ) = @_;
+        my ($self ) = @_;
         my $retval;
 
 
         my $mcpconfig = Tapper::MCP::Config->new($self->testrun);
-        $self->log->debug("Create install config for $hostname");
         my $config   = $mcpconfig->create_config();
         return $config if not ref($config) eq 'HASH';
 
-        $retval = $mcpconfig->write_config($config, "$hostname-install");
+        my $hostname = $self->testrun->testrun_scheduling->host->name;
+        my $config_file_name = "$hostname-install-".$self->testrun->id;
+
+        $retval = $mcpconfig->write_config($config, $config_file_name);
         return $retval if $retval;
 
         if ($config->{autoinstall} or $mcpconfig->mcp_info->skip_install) {
@@ -95,6 +98,7 @@ sub generate_configs
                         my $prc_config = merge($common_config, $testconfigs->[$i]);
                         $prc_config->{guest_number} = $i;
                         my $suffix = "test-prc$i";
+                        $suffix   .= "-".$self->testrun->id;
 
                         $retval = $mcpconfig->write_config($prc_config, "$hostname-$suffix");
                         return $retval if $retval;
@@ -129,6 +133,8 @@ sub report_mcp_results
                 $headerlines = $self->prc_headerlines($prc_number);
                 $self->tap_report_send($prc_results, $headerlines);
         }
+        $self->console_stop();
+
         $self->upload_files($report_id, $self->testrun->id );
 }
 
@@ -146,10 +152,12 @@ sub handle_error
 
 sub start_testrun
 {
-        my ($self, $hostname, $config) = @_;
+        no warnings "experimental::smartmatch";
+        my ($self, $config) = @_;
 
         my $net    = Tapper::MCP::Net->new();
         $net->cfg->{testrun_id} = $self->testrun->id;
+        my $hostname = $self->testrun->testrun_scheduling->host->name;
         given(lc($self->mcp_info->test_type)){
                 when('simnow'){
                         $self->log->debug("Starting Simnow on $hostname");
@@ -174,9 +182,10 @@ sub start_testrun
                 when('local') {
                         $self->log->debug("Starting LOCAL testrun on $hostname");
                         my $local_retval;
+                        my $tr_id = $self->testrun->id;
                         my $path_to_config = $self->mcp_info->skip_install ?
-                          $config->{paths}{localdata_path}."/$hostname-test-prc0" :
-                            $config->{paths}{localdata_path}."/$hostname-install";
+                          $config->{paths}{localdata_path}."/$hostname-test-prc0-$tr_id" :
+                            $config->{paths}{localdata_path}."/$hostname-install-$tr_id";
                         $local_retval = $net->start_local($path_to_config);
                         if ($local_retval) {
                                 $self->handle_error("Starting Tapper on testmachine with SSH", $local_retval);
@@ -189,7 +198,7 @@ sub start_testrun
                         return $self->handle_error("Writing grub file", $grub_retval) if $grub_retval;
 
                         $self->log->debug("rebooting $hostname");
-                        my $reboot_retval = $net->reboot_system($hostname);
+                        my $reboot_retval = $self->host_start();
                         if ($reboot_retval) {
                                 $self->handle_error("Booting machine", $reboot_retval);
                                 return $reboot_retval;
@@ -211,7 +220,9 @@ sub start_testrun
 sub runtest_handling
 {
 
-        my  ($self, $hostname, $revive) = @_;
+        my  ($self, $revive) = @_;
+
+        $self->console_start();
 
         $0 = "tapper-mcp-child-".$self->testrun->id;
         $SIG{USR1} = sub {
@@ -225,11 +236,11 @@ sub runtest_handling
         my $net    = Tapper::MCP::Net->new();
         $net->cfg->{testrun_id} = $self->testrun->id;
 
-        my $config = $self->generate_configs($hostname);
+        my $config = $self->generate_configs();
         return $self->handle_error("Generating configs", $config) if ref $config ne 'HASH';
 
         if ($config->{testrun_stop}) {
-                my $host = model('TestrunDB')->resultset('Host')->search({name => $hostname});
+                my $host = $self->testrun->testrun_scheduling->host;
                 $host->active(0);
                 $host->comment($host->comment."(deactivated by testrun".$self->testrun->id.")");
                 $host->update;
@@ -240,7 +251,7 @@ sub runtest_handling
         $self->state->state_init($self->mcp_info->get_state_config, $revive );
 
         if ($self->state->compare_given_state('reboot_install') == 1) { # before reboot_install?
-                my $error = $self->start_testrun($hostname, $config);
+                my $error = $self->start_testrun($config);
                 return $error if $error;
 
                 my $message = model('TestrunDB')->resultset('Message')->new
@@ -263,11 +274,11 @@ sub runtest_handling
 
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -322,7 +333,6 @@ Sends a tap report because an error occured.
 
 Start Installer on testmachine based on the type of testrun.
 
-@param string   - host name
 @param hash ref - config
 
 @return success - 0
@@ -360,17 +370,26 @@ Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
