@@ -1,13 +1,9 @@
 package Tapper::MCP::Config;
-BEGIN {
-  $Tapper::MCP::Config::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Config::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::Config::VERSION = '5.0.0';
 use strict;
 use warnings;
+no warnings "experimental::smartmatch";
 
 use 5.010;
 use Data::DPath 'dpath';
@@ -115,6 +111,7 @@ sub handle_guest_tests
 
 sub parse_virt_host
 {
+        no warnings "experimental::smartmatch";
         my ($self, $config, $virt) = @_;
         given (lc($virt->{host}->{root}->{precondition_type})) {
                 when ('image') {
@@ -163,6 +160,7 @@ sub parse_virt_preconditions
 
                 # if we have a qcow image, we need a raw image to copy PRC stuff to
                 no warnings 'uninitialized';
+                no warnings "experimental::smartmatch";
                 given($guest->{root}{mounttype})
                 {
                         when ('raw') {
@@ -452,6 +450,7 @@ sub produce_preconds_in_arrayref
 
 sub produce_virt_precondition
 {
+        no warnings "experimental::smartmatch";
         my ($self, $config, $precondition) = @_;
         local $Data::DPath::USE_SAFE; # path not from user, Safe.pm deactivated for debug and speed
         my $producers = $precondition ~~ dpath '//*[key eq "precondition_type" and lc(value) eq "produce"]/../..';
@@ -481,6 +480,7 @@ sub produce_virt_precondition
 
 sub parse_precondition
 {
+        no warnings "experimental::smartmatch";
         my ($self, $config, $precondition_result) = @_;
         my $precondition = $precondition_result->precondition_as_hash;
 
@@ -653,7 +653,8 @@ sub get_common_config
 
         if ($self->testrun->scenario_element) {
                 $config->{scenario_id} = $self->testrun->scenario_element->scenario_id;
-                my $path = $config->{paths}{sync_path}."/".$config->{scenario_id}."/";
+                $config->{paths}{sync_path}.="/".$config->{scenario_id}."/";
+                my $path = $config->{paths}{sync_path};
                 $config->{files}{sync_file} = "$path/syncfile";
 
                 if ($self->testrun->scenario_element->peer_elements->search({}, {rows => 1})->first->testrun->id == $testrun->id) {
@@ -669,17 +670,21 @@ sub get_common_config
                                         return "Can't create $file: $message";
                                 }
                         }
-                        my @peers = map {$_->testrun->testrun_scheduling->host->name} $self->testrun->scenario_element->peer_elements->all;
-                        if (sysopen(my $fh, $config->{files}{sync_file}, O_CREAT | O_EXCL |O_RDWR )) {
-                                print $fh $self->testrun->scenario_element->peer_elements->count;
-                                close $fh;
-                        }       # else trust the creator
-                        my $error;
-                        try {
-                                YAML::DumpFile($config->{files}{sync_file}, \@peers);
-                        } catch { $error = $_};
-                        return $error if $error;
 
+                        # shortest way to deal with undefined options
+                        if (not eval {$self->testrun->scenario_element->scenario->options->{no_sync}})
+                        {
+                                my @peers = map {$_->testrun->testrun_scheduling->host->name} $self->testrun->scenario_element->peer_elements->all;
+                                if (sysopen(my $fh, $config->{files}{sync_file}, O_CREAT | O_EXCL |O_RDWR )) {
+                                        print $fh $self->testrun->scenario_element->peer_elements->count;
+                                        close $fh;
+                                } # else trust the creator
+                                my $error;
+                                try {
+                                        YAML::DumpFile($config->{files}{sync_file}, \@peers);
+                                } catch { $error = $_};
+                                return $error if $error;
+                        }
                 }
         }
         return ($config);
@@ -729,11 +734,11 @@ sub write_config
 
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -1023,17 +1028,26 @@ Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
