@@ -1,11 +1,6 @@
 package Tapper::MCP::Control;
-BEGIN {
-  $Tapper::MCP::Control::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Control::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::Control::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -27,25 +22,26 @@ around BUILDARGS => sub {
 
 
         my $args;
-        if ( @_ == 1 and not $_[0] eq 'HASH' ) {
-                $args = $class->$orig(testrun => $_[0]);
-        } else {
-                $args = $class->$orig(@_);
+        if ( @_ == 1) {
+                if (not ref $_[0] eq 'HASH' )  {
+                        $args->{testrun} = $_[0];
+                } else {
+                        $args = shift;
+                }
+                if (not ref $args->{testrun}) {
+                        $args->{testrun} = model->resultset('Testrun')->find($args->{testrun});
+                }
+                return $args;
         }
-        if (not ref $args->{testrun}) {
-                $args->{testrun} = model->resultset('Testrun')->find($args->{testrun});
-        }
-        return $args;
-
 };
 
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -84,17 +80,26 @@ Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
