@@ -1,10 +1,6 @@
 package Tapper::MCP::Info;
-BEGIN {
-  $Tapper::MCP::Info::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Info::VERSION = '4.1.2';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::Info::VERSION = '5.0.0';
 use 5.010;
 
 use Moose;
@@ -184,6 +180,11 @@ sub get_state_config
                                 };
                 push @{$state->{prcs}}, $prc_state;
         }
+
+        # when we don't install, PRC 0 starts in state 'boot'
+        if ($self->mcp_info->{skip_install}) {
+                $state->{prcs}->[0]->{current_state} = 'boot';
+        }
         return $state;
 }
 
@@ -191,16 +192,17 @@ sub get_state_config
 sub skip_install {
         my ($self, $skip_install) = @_;
         $self->mcp_info->{skip_install} = $skip_install if $skip_install;
+
         return $self->mcp_info->{skip_install};
 }
 
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -372,17 +374,26 @@ Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
