@@ -1,11 +1,6 @@
 package Tapper::MCP::Net::Reset::DoNothing;
-BEGIN {
-  $Tapper::MCP::Net::Reset::DoNothing::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Net::Reset::DoNothing::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::Net::Reset::DoNothing::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -25,25 +20,35 @@ sub reset_host
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Tapper::MCP::Net::Reset::DoNothing
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
