@@ -1,11 +1,6 @@
 package Tapper::MCP::Net::Reset::OSRC;
-BEGIN {
-  $Tapper::MCP::Net::Reset::OSRC::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Net::Reset::OSRC::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::Net::Reset::OSRC::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -98,11 +93,11 @@ sub reset_host
 
 1;
 
-
+__END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -156,20 +151,26 @@ whether the reset really worked.
 @return success - (0, ignore)
 @return error   - (1, error string)
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
-
-__END__
-
