@@ -1,11 +1,6 @@
 package Tapper::MCP::Net::Reset::PM211MIP;
-BEGIN {
-  $Tapper::MCP::Net::Reset::PM211MIP::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Net::Reset::PM211MIP::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::Net::Reset::PM211MIP::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -47,11 +42,11 @@ sub reset_host
 
 1;
 
-
+__END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -94,20 +89,26 @@ The primary plugin function.
 It is called with the Tapper::MCP::Net object (for Tapper logging),
 the hostname to reset and the options from the config file.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
-
-__END__
-
