@@ -1,11 +1,6 @@
 package Tapper::MCP::Net::TAP;
-BEGIN {
-  $Tapper::MCP::Net::TAP::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Net::TAP::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::Net::TAP::VERSION = '5.0.0';
 use 5.010;
 use strict;
 use warnings;
@@ -171,9 +166,10 @@ sub upload_files
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -239,17 +235,26 @@ Upload files written in one stage of the testrun to report framework.
 @return success - 0
 @return error   - error string
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
