@@ -1,14 +1,9 @@
 ## no critic (RequireUseStrict)
 package Tapper::MCP::Scheduler::Algorithm;
-BEGIN {
-  $Tapper::MCP::Scheduler::Algorithm::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Scheduler::Algorithm::VERSION = '4.1.2';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: name of the queue has to be unique
-
-        use 5.010;
+$Tapper::MCP::Scheduler::Algorithm::VERSION = '5.0.0';
+use 5.010;
         use Moose;
         use Tapper::Model 'model';
 
@@ -35,11 +30,11 @@ BEGIN {
         with 'MooseX::Traits';
 1;
 
-
+__END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -71,20 +66,26 @@ Update the time entry of the given queue
 
 @return success - 0
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
-
-__END__
-
