@@ -1,14 +1,9 @@
 ## no critic (RequireUseStrict)
 package Tapper::MCP::Scheduler::Builder;
-BEGIN {
-  $Tapper::MCP::Scheduler::Builder::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Scheduler::Builder::VERSION = '4.1.2';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Generate Testruns
-
-        use Moose;
+$Tapper::MCP::Scheduler::Builder::VERSION = '5.0.0';
+use Moose;
 
 
         sub build {
@@ -21,9 +16,10 @@ BEGIN {
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -39,17 +35,26 @@ Create files needed for a testrun and put it into db.
 
 @return success - testrun id
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
