@@ -1,13 +1,8 @@
 ## no critic (RequireUseStrict)
 package Tapper::MCP::Scheduler::Controller;
-BEGIN {
-  $Tapper::MCP::Scheduler::Controller::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Scheduler::Controller::VERSION = '4.1.2';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Main class of the scheduler
-
+$Tapper::MCP::Scheduler::Controller::VERSION = '5.0.0';
 use 5.010;
 use Moose;
 use base "Tapper::Base";
@@ -183,9 +178,10 @@ sub mark_job_as_finished {
 1;                           # End of Tapper::MCP::Scheduler::Controller
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -212,17 +208,26 @@ fits any of the free hosts.
 @return success   - job object
 @return no job    - 0
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
