@@ -1,11 +1,6 @@
 package Tapper::MCP::Scheduler::Host;
-BEGIN {
-  $Tapper::MCP::Scheduler::Host::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Scheduler::Host::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::Scheduler::Host::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -55,11 +50,11 @@ has features   => (is => 'ro',
 
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -87,17 +82,26 @@ Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
