@@ -1,11 +1,6 @@
 package Tapper::MCP::Scheduler::Job;
-BEGIN {
-  $Tapper::MCP::Scheduler::Job::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Scheduler::Job::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::Scheduler::Job::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -96,6 +91,7 @@ sub match_host {
 
 our @functions;
 BEGIN {
+        no warnings "experimental::smartmatch";
         my $features = Tapper::Model::model->resultset('HostFeature')->search(
                                                                               {
                                                                               },
@@ -217,11 +213,11 @@ sub fits {
 
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -249,17 +245,26 @@ Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
