@@ -1,13 +1,8 @@
 # critic (RequireUseStrict)
 package Tapper::MCP::Scheduler::PrioQueue;
-BEGIN {
-  $Tapper::MCP::Scheduler::PrioQueue::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::Scheduler::PrioQueue::VERSION = '4.1.2';
-}
+our $AUTHORITY = 'cpan:TAPPER';
  # ABSTRACT: Object for test queue abstraction
-
+$Tapper::MCP::Scheduler::PrioQueue::VERSION = '5.0.0';
 use 5.010;
 use Moose;
 
@@ -81,11 +76,11 @@ sub get_first_fitting {
 
 1;
 
-
+__END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -113,20 +108,26 @@ Call the producer method associated with this object.
 @return success - test run id
 @return error   - exception
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
-
-__END__
-
