@@ -1,14 +1,10 @@
 package Tapper::MCP::State;
-BEGIN {
-  $Tapper::MCP::State::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::State::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::State::VERSION = '5.0.0';
 use 5.010;
 use strict;
 use warnings;
+no warnings "experimental::smartmatch";
 
 use Moose;
 use List::Util qw/max min reduce/;
@@ -146,6 +142,7 @@ sub compare_given_state
 
 sub get_current_timeout_span
 {
+        no warnings "experimental::smartmatch";
         my ($self) = @_;
         my $new_timeout_date;
         my $keep_alive_timeout_date = $self->state_details->keep_alive_timeout_date;
@@ -179,6 +176,7 @@ sub state_init
 
 sub update_installer_timeout
 {
+        no warnings "experimental::smartmatch";
         my ($self) = @_;
         my $now = time();
         my $installer_timeout_date = $self->state_details->installer_timeout_current_date;
@@ -199,6 +197,7 @@ sub update_installer_timeout
 
 sub update_prc_timeout
 {
+        no warnings "experimental::smartmatch";
         my ($self, $prc_number) = @_;
         my $now = time();
         if ($self->state_details->prc_timeout_current_date($prc_number) < $now) {
@@ -230,6 +229,7 @@ sub update_prc_timeout
 
 sub update_test_timeout
 {
+        no warnings "experimental::smartmatch";
         my ($self) = @_;
         my $now = time();
 
@@ -303,6 +303,7 @@ sub update_keep_alive_timeout
 
 
 sub update_timeouts {
+        no warnings "experimental::smartmatch";
         my ($self) = @_;
         my ( $error, $timeout_span );
 
@@ -566,6 +567,7 @@ sub msg_keep_alive
 
 sub next_state
 {
+        no warnings "experimental::smartmatch";
         my ($self, $msg) = @_;
         my ($error, $timeout_span);
 
@@ -642,9 +644,10 @@ sub testrun_finished
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -891,17 +894,26 @@ Tells caller whether the testrun is already finished or not.
 @return TR     finished - 1
 @return TR not finished - 0
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
