@@ -1,14 +1,10 @@
 package Tapper::MCP::State::Details;
-BEGIN {
-  $Tapper::MCP::State::Details::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::State::Details::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::State::Details::VERSION = '5.0.0';
 use 5.010;
 use strict;
 use warnings;
+no warnings "experimental::smartmatch";
 
 use Moose;
 use List::Util qw/max min/;
@@ -238,6 +234,7 @@ sub is_all_prcs_finished
 
 sub prc_next_timeout
 {
+        no warnings "experimental::smartmatch";
         my ($self, $num) = @_;
         my $prc = $self->state_details->{prcs}->[$num];
         my $default_timeout = 60 + 60; # (time between SIGTERM and SIGKILL in PRC) + (grace period for sending the message)
@@ -311,9 +308,10 @@ sub get_min_prc_timeout
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -484,17 +482,26 @@ seconds.
 
 @return timeout span for the next state change during testing
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
