@@ -1,11 +1,6 @@
 package Tapper::MCP::State::Plugin::Dummy;
-BEGIN {
-  $Tapper::MCP::State::Plugin::Dummy::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::MCP::State::Plugin::Dummy::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::MCP::State::Plugin::Dummy::VERSION = '5.0.0';
 use strict;
 use warnings;
 use Tapper::MCP::Net::Reset::DoNothing;
@@ -47,9 +42,10 @@ sub keep_alive
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -85,17 +81,26 @@ Handle keep_alive timeout.
 @return success - (0, timeout span)
 @return error   - (1, undef)
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
